function map(value, sourceBottom, sourceTop, targetBottom, targetTop) {
  let valueRatio = (value-sourceBottom)/(sourceTop-sourceBottom);
  return ((targetTop-targetBottom)*valueRatio)+targetBottom;
}

export function interpolateColors(value, sourceBottom, sourceTop, color1, color2) {
  let newColor = [
    map(value, sourceBottom, sourceTop, color1[0], color2[0]),
    map(value, sourceBottom, sourceTop, color1[1], color2[1]),
    map(value, sourceBottom, sourceTop, color1[2], color2[2])
  ];
  return newColor;
}

export function addCommas(nStr) {
    if (nStr < 1000) { return nStr; }
    nStr += '';
    let x = nStr.split('.');
    let x1 = x[0];
    let x2 = x.length > 1 ? '.' + x[1] : '';
    let rgx = /(\d+)(\d{3})/;
    while (rgx.test(x1)) {
            x1 = x1.replace(rgx, '$1' + ',' + '$2');
    }
    return x1 + x2;
}

// Add zero in front of numbers < 10
export function zeroPad(i) {
  if (i < 10) {
    i = "0" + i;
  }
  return i;
}

/**
 * Converts an HSL color value to RGB. Conversion formula
 * adapted from http://en.wikipedia.org/wiki/HSL_color_space.
 * Assumes h, s, and l are contained in the set [0, 1] and
 * returns r, g, and b in the set [0, 255].
 *
 * @param   {number}  h       The hue
 * @param   {number}  s       The saturation
 * @param   {number}  l       The lightness
 * @return  {Array}           The RGB representation
 */
function hslToRgb(h, s, l) {
  var r, g, b;

  if (s == 0) {
    r = g = b = l; // achromatic
  } else {
    var hue2rgb = function hue2rgb (p, q, t) {
      if(t < 0) t += 1;
      if(t > 1) t -= 1;
      if(t < 1/6) return p + (q - p) * 6 * t;
      if(t < 1/2) return q;
      if(t < 2/3) return p + (q - p) * (2/3 - t) * 6;
      return p;
    }

    var q = l < 0.5 ? l * (1 + s) : l + s - l * s;
    var p = 2 * l - q;
    r = hue2rgb(p, q, h + 1/3);
    g = hue2rgb(p, q, h);
    b = hue2rgb(p, q, h - 1/3);
  }

  return [Math.round(r * 255), Math.round(g * 255), Math.round(b * 255)];
}

function rgbToHex(r, g, b) {
  return "#" + ((1 << 24) + (r << 16) + (g << 8) + b).toString(16).slice(1);
}

export function hslToHex(h, s, l) {
  let rgb = hslToRgb(h, s, l);
  return rgbToHex(rgb[0],rgb[1],rgb[2]);
}